# This is the distutils setup script for pogles.
#
# Copyright (c) 2012 Riverbank Computing Limited.


import os
import sys

# Check sip is available.
try:
    import sipconfig
except ImportError:
    sys.stderr.write(
            "Unable to import sipconfig.py - make sure sip is installed\n")
    sys.exit(1)

sipcfg = sipconfig.Configuration()

if '-snapshot-' not in sipcfg.sip_version_str and sipcfg.sip_version < 0x040e02:
    sipconfig.error("SIP v4.14.2 or later is required but found v%s" % sipcfg.sip_version_str)

import sipdistutils

from distutils.core import setup, Extension


# The version number.
from pogles import __version__ as version


# Try and work out the platform.
if os.access('/opt/vc/include/bcm_host.h', os.F_OK):
    platform = 'rpi'
    platform_tag = 'PP_RPI'
    platform_libraries = ['bcm_host']
    include_dirs = ['/opt/vc/include',
            '/opt/vc/include/interface/vcos/pthreads']
    library_dirs = ['/opt/vc/lib']
else:
    # The most common and generic platform is X11 so default to it.
    platform = 'x11'
    platform_tag = 'PP_X11'
    platform_libraries = ['X11']
    include_dirs = []
    library_dirs = []


# The sip command line flags.
swig_opts = ['-o', '-t', platform_tag]

if sipcfg.py_version < 0x030000:
    swig_opts.extend(['-x', 'Py_v3'])

# Define the extension modules.
platform_mod = Extension('platform',
        ['sip/platform/%s/pp_%s.sip' % (platform, platform)],
        swig_opts=swig_opts, include_dirs=include_dirs,
        library_dirs=library_dirs, libraries=platform_libraries)

egl_mod = Extension('egl', ['sip/egl/egl.sip'], swig_opts=swig_opts,
        include_dirs=include_dirs, library_dirs=library_dirs,
        libraries=['EGL', 'GLESv2'])

gles2_mod = Extension('gles2', ['sip/gles2/gles2.sip'], swig_opts=swig_opts,
        include_dirs=include_dirs, library_dirs=library_dirs,
        libraries=['GLESv2'])


# Get the long description for PyPI.
with open('README') as readme:
    long_description = readme.read()

setup(
        name='pogles',
        version=version,
        description='Python Bindings for OpenGL ES v2.0',
        long_description=long_description,
        author='Riverbank Computing Limited',
        author_email='info@riverbankcomputing.com',
        url='http://www.riverbankcomputing.com/software/pogles/',
        license='BSD',
        platforms=['X11', 'Raspberry Pi'],
        packages=['pogles'],
        ext_package='pogles',
        ext_modules=[platform_mod, egl_mod, gles2_mod],
        cmdclass={'build_ext': sipdistutils.build_ext}
     )
